Length is a model of encoding information on how to format date and time by specifying the preferred length ! of date and time fields.
It is intended to represent dateStyle and timeStyle from ECMA 402 DateTimeFormat constructor options.
If either of the fields is omitted, the value will be formatted according to the pattern associated with the ! preferred length of the present field in a given locale.
If both fields are present, both parts of the value will be formatted and an
additional connector pattern ! will be used to construct a full result.
The type of the connector is determined by the length of the Date field.