Date

Enum Date 

#[non_exhaustive]
pub enum Date { Full, Long, Medium, Short, }
Represents different lengths a date part can be formatted into. Each length has associated best pattern for it for a given locale.

The available lengths correspond to UTS #35: Unicode LDML 4. Dates, section 2.4 Element dateFormats.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Full

Full length, usually with weekday name.

Examples

  • Tuesday, January 21, 2020 (en-US)
  • wtorek, 21 stycznia, 2020 (pl)
  • الثلاثاء، ٢١ يناير ٢٠٢٠ (ar)
  • вторник, 21 января 2020 г. (ru)
  • 2020年1月21日火曜日 (ja)


Long

Long length, with wide month name.

Examples

  • September 10, 2020 (en-US)
  • 10 września 2020 (pl)
  • ١٠ سبتمبر ٢٠٢٠ (ar)
  • 10 сентября 2020 г. (ru)
  • 2020年9月10日 (ja)


Medium

Medium length.

Examples

  • Feb 20, 2020 (en-US)
  • 20 lut 2020 (pl)
  • ٢٠‏/٠٢‏/٢٠٢٠ (ar)
  • 20 февр. 2020 г. (ru)
  • 2020/02/20 (ja)


Short

Short length, usually with numeric month.

Examples

  • 1/30/20 (en-US)
  • 30.01.2020 (pl)
  • ٣٠‏/١‏/٢٠٢٠ (ar)
  • 30.01.2020 (ru)
  • 2020/01/30 (ja)