#[non_exhaustive]pub enum Time {
Full,
Long,
Medium,
Short,
}Expand description
Represents different length lengths a time part can be formatted into. Each length has associated best pattern for it for a given locale.
The available lengths correspond to UTS #35: Unicode LDML 4. Dates, section 2.4 [Element timeFormats].
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Full
Full length, with spelled out time zone name.
Examples
- 8:25:07 AM Pacific Standard Time (
en-US) - 08:25:07 czas pacyficzny standardowy (
pl) - ٨:٢٥:٠٧ ص توقيت المحيط الهادي الرسمي (
ar) - 08:25:07 Тихоокеанское стандартное время (
ru) - 8時25分07秒 アメリカ太平洋標準時 (
ja)
Long
Full length, usually with short time-zone code.
Examples
- 8:25:07 AM PST (
en-US) - 08:25:07 GMT-8 (
pl) - ٨:٢٥:٠٧ ص غرينتش-٨ (
ar) - 08:25:07 GMT-8 (
ru) - 8:25:07 GMT-8 (
ja)
Medium
Full length, usually with seconds.
Examples
- 8:25:07 AM (
en-US) - 08:25:07 (
pl) - ٨:٢٥:٠٧ ص (
ar) - 08:25:07 (
ru) - 8:25:07 (
ja)
Short
Full length, usually without seconds.
Examples
- 8:25 AM (
en-US) - 08:25 (
pl) - ٨:٢٥ ص (
ar) - 08:25 (
ru) - 8:25 (
ja)